@@ -7,17 +7,18 @@ using NAPS2.ImportExport.Email;
 
 namespace NAPS2.Modules;
 
-public class MacModule : GuiModule
+public class MacModule : Module
 {
     protected override void Load(ContainerBuilder builder)
     {
-        base.Load(builder);
-
         builder.RegisterType<MacApplicationLifecycle>().As<ApplicationLifecycle>();
         builder.RegisterType<MacScannedImagePrinter>().As<IScannedImagePrinter>();
         builder.RegisterType<AppleMailEmailProvider>().As<IAppleMailEmailProvider>();
         builder.RegisterType<MacIconProvider>().As<IIconProvider>();
         builder.RegisterType<MacServiceManager>().As<IOsServiceManager>();
+        builder.RegisterType<MacOpenWith>().As<IOpenWith>();
+        builder.RegisterType<AppleMailEmailProvider>().As<IEmailProvider>().WithParameter("systemDefault", true);
+        builder.RegisterType<StubSystemEmailClients>().As<ISystemEmailClients>();
 
         builder.RegisterType<MacDesktopForm>().As<DesktopForm>();
         builder.RegisterType<MacPreviewForm>().As<PreviewForm>();
