@@ -53,7 +53,8 @@ public class DesktopController
         DialogHelper dialogHelper,
         DesktopImagesController desktopImagesController, IDesktopScanController desktopScanController,
         DesktopFormProvider desktopFormProvider, IScannedImagePrinter scannedImagePrinter,
-        ISharedDeviceManager sharedDeviceManager, ProcessCoordinator processCoordinator, RecoveryManager recoveryManager)
+        ISharedDeviceManager sharedDeviceManager, ProcessCoordinator processCoordinator,
+        RecoveryManager recoveryManager)
     {
         _scanningContext = scanningContext;
         _imageList = imageList;
@@ -181,6 +182,7 @@ public class DesktopController
             {
                 _scanningContext.Dispose();
                 _recoveryStorageManager.Dispose();
+                _imageList.Images.DisposeAll();
             }
             catch (Exception ex)
             {
@@ -524,7 +526,8 @@ public class DesktopController
         _suspended = false;
     }
 
-    private class ProcessCoordinatorServiceImpl(DesktopController controller) : ProcessCoordinatorService.ProcessCoordinatorServiceBase
+    private class ProcessCoordinatorServiceImpl(DesktopController controller)
+        : ProcessCoordinatorService.ProcessCoordinatorServiceBase
     {
         public override Task<Empty> Activate(ActivateRequest request, ServerCallContext context)
         {
@@ -553,11 +556,11 @@ public class DesktopController
             {
                 controller._desktopFormProvider.DesktopForm.Close();
 #if NET6_0_OR_GREATER
-            if (OperatingSystem.IsMacOS())
-            {
-                // Closing the main window isn't enough to quit the app on Mac
-                Application.Instance.Quit();
-            }
+                if (OperatingSystem.IsMacOS())
+                {
+                    // Closing the main window isn't enough to quit the app on Mac
+                    Application.Instance.Quit();
+                }
 #endif
             });
             return Task.FromResult(new Empty());
@@ -575,5 +578,12 @@ public class DesktopController
                 await controller._desktopScanController.ScanWithDevice(request.Device));
             return Task.FromResult(new Empty());
         }
+
+        public override Task<StopSharingServerResponse> StopSharingServer(StopSharingServerRequest request,
+            ServerCallContext context)
+        {
+            controller._sharedDeviceManager.InvokeSharingServerStopped();
+            return Task.FromResult(new StopSharingServerResponse());
+        }
     }
 }
\ No newline at end of file
