@@ -33,6 +33,7 @@ public abstract class DesktopForm : EtoFormBase
 
     protected readonly ListProvider<Command> _scanMenuCommands = new();
     private readonly ListProvider<Command> _languageMenuCommands = new();
+    protected readonly ListProvider<Command> _editWithCommands = new();
     private readonly ContextMenu _contextMenu = new();
 
     private readonly NotificationArea _notificationArea;
@@ -82,6 +83,7 @@ public abstract class DesktopForm : EtoFormBase
         _keyboardShortcuts.Assign(Commands);
         CreateToolbarsAndMenus();
         UpdateScanButton();
+        EditWithAppChanged();
         UpdateProfilesToolbar();
         InitLanguageDropdown();
 
@@ -328,6 +330,9 @@ public abstract class DesktopForm : EtoFormBase
                 .Append(Commands.Split)
                 .Append(Commands.Combine)
                 .Separator()
+                .Dynamic(_editWithCommands)
+                .Append(Commands.EditWithPick)
+                .Separator()
                 .Append(Commands.ResetImage));
         if (!hiddenButtons.HasFlag(ToolbarButtons.Rotate))
             CreateToolbarMenu(Commands.RotateMenu, GetRotateMenuProvider());
@@ -514,14 +519,14 @@ public abstract class DesktopForm : EtoFormBase
         // "All" dropdown items
         Commands.SaveAllPdf.Text = Commands.SaveAllImages.Text = Commands.EmailAll.Text =
             Commands.ReverseAll.Text = string.Format(MiscResources.AllCount, ImageList.Images.Count);
-        Commands.SaveAllPdf.Enabled = Commands.SaveAllImages.Enabled = Commands.EmailAll.Enabled =
-            Commands.ReverseAll.Enabled = ImageList.Images.Any();
+        Commands.SaveAllPdf.Enabled = Commands.SaveAllImages.Enabled = Commands.SaveAll.Enabled =
+            Commands.EmailAll.Enabled = Commands.ReverseAll.Enabled = ImageList.Images.Any();
 
         // "Selected" dropdown items
         Commands.SaveSelectedPdf.Text = Commands.SaveSelectedImages.Text = Commands.EmailSelected.Text =
             Commands.ReverseSelected.Text = string.Format(MiscResources.SelectedCount, ImageList.Selection.Count);
-        Commands.SaveSelectedPdf.Enabled = Commands.SaveSelectedImages.Enabled = Commands.EmailSelected.Enabled =
-            Commands.ReverseSelected.Enabled = ImageList.Selection.Any();
+        Commands.SaveSelectedPdf.Enabled = Commands.SaveSelectedImages.Enabled = Commands.SaveSelected.Enabled =
+            Commands.EmailSelected.Enabled = Commands.ReverseSelected.Enabled = ImageList.Selection.Any();
 
         // Other
         Commands.SelectAll.Enabled = ImageList.Images.Any();
@@ -553,6 +558,20 @@ public abstract class DesktopForm : EtoFormBase
         _scanMenuCommands.Value = commandList;
     }
 
+    public void EditWithAppChanged()
+    {
+        var appName = Config.Get(c => c.EditWithAppName);
+        if (!string.IsNullOrEmpty(appName))
+        {
+            Commands.EditWithApp.Text = string.Format(UiStrings.EditWithAppName, appName);
+            _editWithCommands.Value = ImmutableList.Create((Command) Commands.EditWithApp);
+        }
+        else
+        {
+            _editWithCommands.Value = ImmutableList<Command>.Empty;
+        }
+    }
+
     protected virtual void UpdateTitle(ScanProfile? defaultProfile)
     {
         Title = string.Format(UiStrings.Naps2TitleFormat, defaultProfile?.DisplayName ?? UiStrings.Naps2FullName);
