@@ -4,11 +4,14 @@ using NAPS2.Scan.Internal.Twain;
 
 namespace NAPS2.Modules;
 
+/// <summary>
+/// Worker-specific module used by WorkerEntryPoint.
+/// </summary>
 public class WorkerModule : Module
 {
     protected override void Load(ContainerBuilder builder)
     {
-        builder.Register(ctx => new ScanningContext(ctx.Resolve<ImageContext>())).SingleInstance();
+        // Bindings for ITwainController as used by WorkerServiceImpl
 #if MAC
         builder.RegisterType<StubTwainController>().As<ITwainController>();
 #elif NET6_0_OR_GREATER
