@@ -5,9 +5,11 @@ namespace NAPS2.Platform;
 /// </summary>
 public interface IOsServiceManager
 {
+    bool CanRegister { get; }
+
     bool IsRegistered { get; }
 
-    void Register();
+    bool Register();
 
     void Unregister();
 }
\ No newline at end of file
