@@ -4,7 +4,7 @@ namespace NAPS2.Scan;
 
 // ScanDevice used to only have ID and Name, but now it has Driver too. We need ScanProfileDevice for backwards compat
 // when serializing.
-public record ScanProfileDevice(string ID, string Name, string? IconUri = null)
+public record ScanProfileDevice(string ID, string Name, string? IconUri = null, string? ConnectionUri = null)
 {
     [return: NotNullIfNotNull("device")]
     public static ScanProfileDevice? FromScanDevice(ScanDevice? device)
@@ -13,12 +13,12 @@ public record ScanProfileDevice(string ID, string Name, string? IconUri = null)
         {
             return null;
         }
-        return new ScanProfileDevice(device.ID, device.Name, device.IconUri);
+        return new ScanProfileDevice(device.ID, device.Name, device.IconUri, device.ConnectionUri);
     }
 
     public ScanDevice ToScanDevice(Driver driver)
     {
-        return new ScanDevice(driver, ID, Name, IconUri);
+        return new ScanDevice(driver, ID, Name, IconUri, ConnectionUri);
     }
 
     private ScanProfileDevice() : this("", "")
