@@ -58,7 +58,8 @@ internal class EsclScanDriver : IScanDriver
             var name = string.IsNullOrEmpty(service.ScannerName)
                 ? $"{ip}"
                 : $"{service.ScannerName} ({ip})";
-            callback(new ScanDevice(Driver.Escl, id, name, new EsclClient(service).IconUri));
+            var client = new EsclClient(service);
+            callback(new ScanDevice(Driver.Escl, id, name, client.IconUri, client.ConnectionUri));
         });
         locator.Logger = _logger;
         locator.Start();
@@ -74,12 +75,11 @@ internal class EsclScanDriver : IScanDriver
     public async Task<ScanCaps> GetCaps(ScanOptions options, CancellationToken cancelToken)
     {
         if (cancelToken.IsCancellationRequested) return new ScanCaps();
-        var client = await GetEsclClient(options, cancelToken);
-        if (client == null) return new ScanCaps();
 
         try
         {
-            var caps = await client.GetCapabilities();
+            var (client, caps) = await GetEsclClientWithCaps(options, cancelToken, ScanEvents.Stub);
+            if (client == null || caps == null) return new ScanCaps();
             return new ScanCaps
             {
                 MetadataCaps = new()
@@ -163,12 +163,11 @@ internal class EsclScanDriver : IScanDriver
         Action<IMemoryImage> callback)
     {
         if (cancelToken.IsCancellationRequested) return;
-        var client = await GetEsclClient(options, cancelToken);
-        if (client == null) return;
 
         try
         {
-            var caps = await client.GetCapabilities();
+            var (client, caps) = await GetEsclClientWithCaps(options, cancelToken, scanEvents);
+            if (client == null || caps == null) return;
             var status = await client.GetStatus();
             bool hasProgressExtension = caps.Naps2Extensions?.Contains("Progress") ?? false;
             bool hasErrorDetailsExtension = caps.Naps2Extensions?.Contains("ErrorDetails") ?? false;
@@ -231,29 +230,71 @@ internal class EsclScanDriver : IScanDriver
         }
     }
 
-    private async Task<EsclClient?> GetEsclClient(ScanOptions options, CancellationToken cancelToken)
+    private async Task<(EsclClient?, EsclCapabilities?)> GetEsclClientWithCaps(ScanOptions options,
+        CancellationToken cancelToken, IScanEvents scanEvents)
     {
         EsclClient client;
         string deviceId = options.Device!.ID;
 
+        void SetUpClient()
+        {
+            client.SecurityPolicy = options.EsclOptions.SecurityPolicy;
+            client.Logger = _logger;
+            client.CancelToken = cancelToken;
+        }
+        void MaybeSendNewUris()
+        {
+            string? iconUri = client.IconUri;
+            string connectionUri = client.ConnectionUri;
+            if (iconUri != options.Device.IconUri || connectionUri != options.Device.ConnectionUri)
+            {
+                scanEvents.DeviceUriChanged(iconUri, connectionUri);
+            }
+        }
+
+        // If we only have a URI to connect, just use it.
         if (deviceId.StartsWith("http://") || deviceId.StartsWith("https://"))
         {
             client = new EsclClient(new Uri(deviceId));
-            // TODO: Handle device offline?
+            SetUpClient();
+            EsclCapabilities caps;
+            try
+            {
+                caps = await client.GetCapabilities();
+            }
+            catch (HttpRequestException)
+            {
+                throw new DeviceOfflineException();
+            }
+            return (client, caps);
         }
-        else
+
+        // If we have both a UUID and a ConnectionUri, race an mDNS request with a GetCapabilities request.
+        // This is the best of both worlds:
+        // - If the connection info is up to date, we connect directly immediately.
+        // - If the IP has changed, we find out and fall back to that
+        // TODO: Maybe racing [GetCapabilities] with [mDNS + GetCapabilities] is slightly more optimal
+        var serviceTask = FindDeviceEsclService(options, cancelToken);
+        if (options.Device!.ConnectionUri != null)
         {
-            var service = await FindDeviceEsclService(options, cancelToken);
-            if (cancelToken.IsCancellationRequested) return null;
-            if (service == null) throw new DeviceOfflineException();
-            client = new EsclClient(service);
+            client = new EsclClient(new Uri(options.Device.ConnectionUri));
+            SetUpClient();
+            var capsTask = client.GetCapabilities();
+            await Task.WhenAny(capsTask, serviceTask);
+            if (capsTask.Status == TaskStatus.RanToCompletion)
+            {
+                return (client, await capsTask);
+            }
         }
 
-        client.SecurityPolicy = options.EsclOptions.SecurityPolicy;
-        client.Logger = _logger;
-        client.CancelToken = cancelToken;
-
-        return client;
+        // If we have no known connection info (or failed to connect with it), use the mDNS response for the client
+        var service = await serviceTask;
+        if (cancelToken.IsCancellationRequested) return (null, null);
+        if (service == null) throw new DeviceOfflineException();
+        client = new EsclClient(service);
+        MaybeSendNewUris();
+        SetUpClient();
+        return (client, await client.GetCapabilities());
     }
 
     private async Task<EsclJob> CreateScanJobAndCorrectInvalidSettings(EsclClient client, EsclScanSettings scanSettings)
