@@ -27,7 +27,15 @@ internal class WiaScanDriver : IScanDriver
             {
                 using (deviceInfo)
                 {
-                    callback(new ScanDevice(Driver.Wia, deviceInfo.Id(), deviceInfo.Name()));
+                    string id = deviceInfo.Id();
+                    string name = deviceInfo.Name();
+                    if (name.Equals(@"No friendly name", StringComparison.InvariantCultureIgnoreCase))
+                    {
+                        // Some Windows/driver issues can result in the scanner name appearing as "No friendly name".
+                        // Better to replace with a generic "Unknown Scanner" string.
+                        name = SdkResources.UnknownScanner;
+                    }
+                    callback(new ScanDevice(Driver.Wia, id, name));
                 }
             }
         });
@@ -315,7 +323,8 @@ internal class WiaScanDriver : IScanDriver
         {
             if (_options.UseNativeUI)
             {
-                bool useWorker = Environment.Is64BitProcess && device.Version == WiaVersion.Wia10;
+                bool useWorker = PlatformCompat.System.SupportsWinX86Worker &&
+                                 device.Version == WiaVersion.Wia10;
                 if (useWorker)
                 {
                     if (_scanningContext.WorkerFactory == null)
