@@ -21,7 +21,8 @@ public class TestCommand : ICommand<TestOptions>
                 Cli.Run("dotnet", $"test -l \"console;verbosity=normal\" {frameworkArg} {project}", new()
                 {
                     { "NAPS2_TEST_DEPS", Path.Combine(Paths.SolutionRoot, depsRootPath) },
-                    { "NAPS2_TEST_NOGUI", opts.NoGui ? "1" : "0" }
+                    { "NAPS2_TEST_NOGUI", opts.NoGui ? "1" : "0" },
+                    { "NAPS2_TEST_NONETWORK", opts.NoNetwork ? "1" : "0" }
                 });
             }
             catch (Exception)
